==> tellico-trinity_3.5.13.2.orig.tar.xz: tellico-trinity-3.5.13.2/src/newstuff/newscript.cpp <==
/***************************************************************************
    copyright            : (C) 2006 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#include "newscript.h"
#include "manager.h"

#include <kurl.h>

#include <tqwidget.h>

using Tellico::NewStuff::NewScript;

NewScript::NewScript(Manager* manager_, TQWidget* parentWidget_)
#if KDE_IS_VERSION(3,3,90)
    : KNewStuffSecure(TQString::fromLatin1("tellico/data-source"), parentWidget_)
#else
    : TQObject(parentWidget_)
#endif
    , m_manager(manager_), m_success(false) {
}

void NewScript::installResource() {
  // m_tarName is protected in superclass
  KURL u;
  u.setPath(m_tarName);
  m_success = m_manager->installScript(u);
  m_url = u;
}

#if KDE_IS_VERSION(3,3,90)
#include <knewstuff/knewstuffsecure.h>
#define SUPERCLASS KNewStuffSecure
#else
#define SUPERCLASS TQObject
#endif

#include "newscript.moc"
#undef SUPERCLASS

==> tellico-trinity_14.1.5.orig.tar.xz: tellico-trinity-14.1.5/src/newstuff/newscript.cpp <==
/***************************************************************************
    copyright            : (C) 2006 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#include "newscript.h"
#include "manager.h"

#include <kurl.h>

#include <tqwidget.h>

using Tellico::NewStuff::NewScript;

NewScript::NewScript(Manager* manager_, TQWidget* parentWidget_)
#if KDE_IS_VERSION(3,3,90)
    : TDENewStuffSecure(TQString::fromLatin1("tellico script"), parentWidget_)
#else
    : TQObject(parentWidget_)
#endif
    , m_manager(manager_), m_success(false) {
}

void NewScript::installResource() {
  // m_tarName is protected in superclass
  KURL u;
  u.setPath(m_tarName);
  m_success = m_manager->installScript(u);
  m_url = u;
}

#if KDE_IS_VERSION(3,3,90)
#include <tdenewstuff/knewstuffsecure.h>
#define SUPERCLASS TDENewStuffSecure
#else
#define SUPERCLASS TQObject
#endif

#include "newscript.moc"
#undef SUPERCLASS
